.. _bokeh.colors:

bokeh.colors
============

.. automodule:: bokeh.colors

.. _bokeh.colors.Color:

bokeh.colors.Color
------------------

.. automodule:: bokeh.colors.color
   :members:
   :inherited-members:

.. _bokeh.colors.HSL:

bokeh.colors.HSL
----------------

.. automodule:: bokeh.colors.hsl
   :members:
   :inherited-members:

.. _bokeh.colors.RGB:

bokeh.colors.RGB
----------------

.. automodule:: bokeh.colors.rgb
   :members:
   :inherited-members:

.. _bokeh.colors.groups:

bokeh.colors.groups
-------------------

.. automodule:: bokeh.colors.groups
   :members:

.. _bokeh.colors.named:

bokeh.colors.named
------------------

.. automodule:: bokeh.colors.named
   :members:
   :undoc-members:
